#include <Servo.h>

#include "HX711.h"


// load variables
const int LOADCELL_DOUT_PIN = 4;
const int LOADCELL_SCK_PIN = 5;
long threshold = 300000;
long reading = 200;


// servo variables  servo 1: 0-170, servo 2: 177-10
// servo start and end values are calibrated so that the motors complete an actual 180 degree turn
int servo1Pin = 9;
int servo2Pin = 10;
int timeDelay = 1000;
int servo1Start = 0;
int servo1End = 170;
int servo2Start = 177;
int servo2End = 10;


HX711 scale;
Servo servo1;
Servo servo2;

void setup() {
  Serial.begin(9600);
  scale.begin(LOADCELL_DOUT_PIN, LOADCELL_SCK_PIN);
  //scale.set_scale(calibration_factor);
  servo1.attach(servo1Pin);
  servo2.attach(servo2Pin);
}

void loop() {
  //constantly sends signal to the servos to keep table still unless there is a load detected
  servo1.write(servo1Start); 
  servo2.write(servo2Start);
  detect_load();
  Serial.print("HX711 reading: ");
  Serial.println(reading);
  if (reading > threshold){   
    flip();
  }
  delay(1000);
}

// a function that detects weight on the table
void detect_load(){
  if (scale.is_ready()){
    reading = scale.read();
  }
  else {
    Serial.println("HX711 not found.");
  }
}

// a function that flips the table, then flips back
void flip() {
  delay(timeDelay); // gives a slight pause before flipping the table
  servo1.write(servo1Start);
  servo2.write(servo2Start);
  delay(2000);
  servo1.write(servo1End);
  servo2.write(servo2End);
  delay(2000);
  servo1.write(servo1Start);
  servo2.write(servo2Start);
}

